using System;
using System.Text;
using Sitecore.Data.Items;
using Sitecore.Diagnostics;
using Sitecore.Events;
using Sitecore.Publishing;

namespace Sitecore.Sample
{
   public class EventHandler
   {
      public void OnPublishEnd(object sender, EventArgs args)
      {
         // 'publish:end' event provides one argument : instance of
         // Sitecore.Publishing.Publisher class performing the actual publish.
         Publisher publisher = Event.ExtractParameter(args, 0) as Publisher;

         // Make sure that we were able to extract the publisher from event
         // An exception is thrown otherways.
         Error.AssertObject(publisher, "Publisher");

         // Write publish information into the log.
         Log.Info(string.Format(
                     "Publish completed. Language: {0}, Target database: {1}",
                     publisher.Options.Language.Name,
                     publisher.Options.TargetDatabase.Name),
            this);

         // Raise the 'publish:end:handled' event and pass two
         // event parameters
         Event.RaiseEvent("publish:end:handled", publisher, this);
      }

      public void OnPublishEndHandled(object sender, EventArgs args)
      {
         object handler = Event.ExtractParameter(args, 1);
         Log.Info(string.Format(
               "publish:end event was handled by instance of the {0} class",
               handler.GetType().Name),
            this);
      }

      public void OnItemMoving(object sender, EventArgs args)
      {
         // get the item that is being moved
         Item item = Event.ExtractParameter(args, 0) as Item;
         if (item != null)
         {
            // If item is moved from the 'UntouchableFolder'
            // then cancel the operation.
            if (item.Parent.Name == "UntouchableFolder")
            {
               ((SitecoreEventArgs)args).Result.Cancel = true;
            }
         }
      }

      public void LogEvent(object sender, EventArgs args)
      {
         SitecoreEventArgs scArgs = args as SitecoreEventArgs;
         StringBuilder result = new StringBuilder();
         if (scArgs == null)
         {
            result.Append("Failed to cast EventArgs to SitecoreEventArgs");
            return;
         }

         result.Append("Event: " + scArgs.EventName + ". ");
         foreach(object parameter in scArgs.Parameters)
         {
            result.Append(string.Format("Parameter: "));
            result.Append(parameter.ToString());
            result.Append(".");
         }
         Log.Info(result.ToString(), this);
      }
   }
}